import React, { useState } from 'react';
import { Image } from 'react-native';
import { handleImageUrl } from './utils';
import { USER_AVATAR_DEFAULT } from '../../constant';

interface IAvatarProps {
  uri: string;
  size?: number;
  radius?: number;
  styles?: Record<string, number|string>
}

export const Avatar = ((props: IAvatarProps) => {
  const {
    uri = '',
    size = 40,
    radius = 20,
    styles = {},
  } = props;

  const [imageUrl, setImageUrl] = useState<string>('');

  const onImageError = () => {
    setImageUrl(USER_AVATAR_DEFAULT);
  };

  return (
    <Image
      style={[{
        width: size,
        height: size,
        borderRadius: radius,
      }, styles]}
      source={{uri: imageUrl ? imageUrl : handleImageUrl(uri)}}
      onError={onImageError}
    />
  );
});
