import React from 'react';
import {
  StyleSheet,
  View,
  Text,
  TouchableOpacity,
  Image,
  SafeAreaView,
} from 'react-native';

import { Avatar } from '../Avatar';

import { useChatContext } from '../../context';

export interface IChatHeaderProps {}

export const ChatHeader = () => {
  const { conversationAvatar, conversationName, navigateBack } = useChatContext();

  return (
    <SafeAreaView>
      <View style={styles.chatHeaderContainer}>
        <TouchableOpacity
          delayPressIn={0}
          activeOpacity={1}
          style={styles.gobackArea}
          onPress={navigateBack}
        >
          <Image
            style={styles.gobackIcon}
            source={require('../../assets/go-back.png')}
          />
        </TouchableOpacity>
        <Avatar uri={conversationAvatar} />
        <View style={styles.chatInfo}>
          <Text
            numberOfLines={1}
            style={styles.chatName}
          >
            {conversationName}
          </Text>
        </View>
      </View>
    </SafeAreaView>
  );
};

const styles = StyleSheet.create({
  chatHeaderContainer: {
    height: 56,
    flexDirection: 'row',
    alignItems: 'center',
    borderBottomWidth: 0.5,
    borderColor: '#DDDDDD',
    backgroundColor: '#FFFFFF',
  },
  gobackArea: {
    width: 40,
    height: '100%',
    alignItems: 'center',
    justifyContent: 'center',
  },
  gobackIcon: {
    width: 9,
    height: 16,
  },
  chatInfo: {
    marginLeft: 8,
  },
  chatName: {
    width: 100,
    fontSize: 14,
    fontWeight: '600',
    color: '#000000',
  },
});
