import React from 'react';
import {
  StyleSheet,
  View,
  Text,
} from 'react-native';
import { Profile } from '@tencentcloud/chat';
import { TUITranslateService } from '@tencentcloud/chat-uikit-engine';

import { UserSelectList, UserSelectedView } from '../../UserSelector';

import { useConversationListContext } from '../../../context/ConversationListContext';

export interface ICreateGroupChatProps {
  selectedUserList: Profile[];
  setSelectedUserList: React.Dispatch<React.SetStateAction<Profile[]>>;
}

export function CreateGroupChat(props: ICreateGroupChatProps) {
  const { selectedUserList, setSelectedUserList} = props;
  const { friendList } = useConversationListContext();

  const getSelectUserList = () => {
    return friendList.map(friend => friend.profile);
  };

  return (
    <View style={styles.container}>
      <View style={styles.userSelectViewContainer}>
        <UserSelectedView
          selectedUserList={selectedUserList}
          setSelectedUserList={setSelectedUserList}
        />
      </View>
      <Text style={styles.contactedTitle}>
        {TUITranslateService.t('Conversation.FREQUENTLY_CONTACTED')}
      </Text>
      <UserSelectList
        userList={getSelectUserList()}
        selectedUserList={selectedUserList}
        setSelectedUserList={setSelectedUserList}
      />
    </View>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
  },
  userSelectViewContainer: {
    flexDirection: 'row',
  },
  contactedTitle: {
    fontSize: 15,
    fontWeight: '600',
    color: '#000000',
    paddingBottom: 18,
  },
});
