import React from 'react';
import { FlatList } from 'react-native';
import { Profile } from '@tencentcloud/chat';

import { UserSelectItem } from './UserSelectItem';

export interface UserSelectListProps {
  userList: Record<string, any>[];
  selectedUserList: Profile[];
  setSelectedUserList: React.Dispatch<React.SetStateAction<Profile[]>>;
}

export function UserSelectList(props: UserSelectListProps) {
  const {
    selectedUserList,
    setSelectedUserList,
    userList,
  } = props;

  const userSelectListChange = (e: any, item: any) => {
    const { userID } = item;
    const { checked } = e.target;
    if (checked) {
      selectedUserList.push(item);
    } else {
      selectedUserList.splice(selectedUserList.findIndex(item => item.userID === userID), 1);
    }
    setSelectedUserList([...selectedUserList]);
  };

  return (
    <FlatList
      data={userList}
      renderItem={({ item }) =>
        <UserSelectItem
          selectedUserList={selectedUserList}
          item={item}
          onChange={(checked: boolean) => {
            userSelectListChange({ target: { checked } }, item);
          }}
        />}
      keyExtractor={(item) => item.userID}
      showsVerticalScrollIndicator={false}
    />
  );
}
